@@ -26,6 +26,8 @@ for t in `find ./tests -name "CMakeLists.txt" | xargs grep smoketests | sed -e '
         if [ "$?" -ne 0 ]; then
            FAIL=1
            echo "FAILED"
+           echo "LOG:"
+           tail -100 ${LOGFILE}
         else
            echo "OK"
         fi
